# Template Creator

> This project is generated by cookiecutter.

This commandline application is built for create new project with specify code template.

## Installation

```bash
# from pypi
pip install tc
```

## Usage

`ttc create --name django`

set environment variable: `export TC_URL="<your prefix>"`

template_dict:

```python
prefix = os.getenv("TC_URL", "git@github.com:svtter")
template_dict = {
    "django": "{prefix}/cookiecutter-django.git".format(prefix=prefix),
    "package": "{prefix}/cookiecutter-pypackage.git".format(prefix=prefix),
    "compose": "{prefix}/cookiecutter-compose.git".format(prefix=prefix),
}
```